@@ -35,10 +35,8 @@ GST_DEBUG_CATEGORY (gst_debug_gtk_base_sink);
 #define GST_CAT_DEFAULT gst_debug_gtk_base_sink
 
 #define DEFAULT_FORCE_ASPECT_RATIO  TRUE
-#define DEFAULT_DISPLAY_PAR_N       0
-#define DEFAULT_DISPLAY_PAR_D       1
-#define DEFAULT_VIDEO_PAR_N         0
-#define DEFAULT_VIDEO_PAR_D         1
+#define DEFAULT_PAR_N               0
+#define DEFAULT_PAR_D               1
 #define DEFAULT_IGNORE_ALPHA        TRUE
 
 static void gst_gtk_base_sink_finalize (GObject * object);
@@ -70,7 +68,6 @@ enum
   PROP_WIDGET,
   PROP_FORCE_ASPECT_RATIO,
   PROP_PIXEL_ASPECT_RATIO,
-  PROP_VIDEO_ASPECT_RATIO_OVERRIDE,
   PROP_IGNORE_ALPHA,
 };
 
@@ -103,9 +100,7 @@ gst_gtk_base_sink_class_init (GstGtkBaseSinkClass * klass)
       g_param_spec_object ("widget", "Gtk Widget",
           "The GtkWidget to place in the widget hierarchy "
           "(must only be get from the GTK main thread)",
-          GTK_TYPE_WIDGET,
-          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS |
-          GST_PARAM_DOC_SHOW_DEFAULT));
+          GTK_TYPE_WIDGET, G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class, PROP_FORCE_ASPECT_RATIO,
       g_param_spec_boolean ("force-aspect-ratio",
@@ -116,24 +111,8 @@ gst_gtk_base_sink_class_init (GstGtkBaseSinkClass * klass)
 
   g_object_class_install_property (gobject_class, PROP_PIXEL_ASPECT_RATIO,
       gst_param_spec_fraction ("pixel-aspect-ratio", "Pixel Aspect Ratio",
-          "The pixel aspect ratio of the device",
-          0, G_MAXINT, G_MAXINT, 1, DEFAULT_DISPLAY_PAR_N,
-          DEFAULT_DISPLAY_PAR_D, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-
-  /**
-   * GstGtkBaseSink:video-aspect-ratio-override:
-   *
-   * The pixel aspect ratio of the video (0/1 = follow stream)
-   *
-   * Since: 1.20
-   */
-  g_object_class_install_property (gobject_class,
-      PROP_VIDEO_ASPECT_RATIO_OVERRIDE,
-      gst_param_spec_fraction ("video-aspect-ratio-override",
-          "Video Pixel Aspect Ratio",
-          "The pixel aspect ratio of the video (0/1 = follow stream)", 0,
-          G_MAXINT, G_MAXINT, 1, DEFAULT_VIDEO_PAR_N, DEFAULT_VIDEO_PAR_D,
-          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          "The pixel aspect ratio of the device", DEFAULT_PAR_N, DEFAULT_PAR_D,
+          G_MAXINT, 1, 1, 1, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class, PROP_IGNORE_ALPHA,
       g_param_spec_boolean ("ignore-alpha", "Ignore Alpha",
@@ -149,18 +128,14 @@ gst_gtk_base_sink_class_init (GstGtkBaseSinkClass * klass)
   gstbasesink_class->stop = gst_gtk_base_sink_stop;
 
   gstvideosink_class->show_frame = gst_gtk_base_sink_show_frame;
-
-  gst_type_mark_as_plugin_api (GST_TYPE_GTK_BASE_SINK, 0);
 }
 
 static void
 gst_gtk_base_sink_init (GstGtkBaseSink * gtk_sink)
 {
   gtk_sink->force_aspect_ratio = DEFAULT_FORCE_ASPECT_RATIO;
-  gtk_sink->par_n = DEFAULT_DISPLAY_PAR_N;
-  gtk_sink->par_d = DEFAULT_DISPLAY_PAR_D;
-  gtk_sink->video_par_n = DEFAULT_VIDEO_PAR_N;
-  gtk_sink->video_par_d = DEFAULT_VIDEO_PAR_D;
+  gtk_sink->par_n = DEFAULT_PAR_N;
+  gtk_sink->par_d = DEFAULT_PAR_D;
   gtk_sink->ignore_alpha = DEFAULT_IGNORE_ALPHA;
 }
 
@@ -201,22 +176,12 @@ static GtkGstBaseWidget *
 gst_gtk_base_sink_get_widget (GstGtkBaseSink * gtk_sink)
 {
   if (gtk_sink->widget != NULL)
-    return g_object_ref (gtk_sink->widget);
-
-  /* Fix segfault when GTK3 and GTK4 are loaded (e.g. `gst-inspect-1.0 -a`)
-   * into the same process.
-   *
-   * GtkNoMediaFile only exists in GTK4 and is registered as part of
-   * gtk_init(). */
-  if (g_type_from_name ("GtkNoMediaFile")) {
-    GST_INFO_OBJECT (gtk_sink, "GTK4 is already initialized");
-    return NULL;
-  }
+    return gtk_sink->widget;
 
   /* Ensure GTK is initialized, this has no side effect if it was already
    * initialized. Also, we do that lazily, so the application can be first */
   if (!gtk_init_check (NULL, NULL)) {
-    GST_INFO_OBJECT (gtk_sink, "Could not ensure GTK initialization.");
+    GST_ERROR_OBJECT (gtk_sink, "Could not ensure GTK initialization.");
     return NULL;
   }
 
@@ -230,18 +195,13 @@ gst_gtk_base_sink_get_widget (GstGtkBaseSink * gtk_sink)
   gtk_sink->bind_pixel_aspect_ratio =
       g_object_bind_property (gtk_sink, "pixel-aspect-ratio", gtk_sink->widget,
       "pixel-aspect-ratio", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-  gtk_sink->bind_video_aspect_ratio =
-      g_object_bind_property (gtk_sink, "video-aspect-ratio-override",
-      gtk_sink->widget, "video-aspect-ratio-override",
-      G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_sink->bind_ignore_alpha =
       g_object_bind_property (gtk_sink, "ignore-alpha", gtk_sink->widget,
       "ignore-alpha", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
 
   /* Take the floating ref, other wise the destruction of the container will
-   * make this widget disappear possibly before we are done. */
-  g_object_ref_sink (gtk_sink->widget);
-
+   * make this widget disapear possibly before we are done. */
+  gst_object_ref_sink (gtk_sink->widget);
   gtk_sink->widget_destroy_id = g_signal_connect (gtk_sink->widget, "destroy",
       G_CALLBACK (widget_destroy_cb), gtk_sink);
 
@@ -249,25 +209,7 @@ gst_gtk_base_sink_get_widget (GstGtkBaseSink * gtk_sink)
   gtk_gst_base_widget_set_element (GTK_GST_BASE_WIDGET (gtk_sink->widget),
       GST_ELEMENT (gtk_sink));
 
-  return g_object_ref (gtk_sink->widget);
-}
-
-GtkWidget *
-gst_gtk_base_sink_acquire_widget (GstGtkBaseSink * gtk_sink)
-{
-  gpointer widget = NULL;
-
-  GST_OBJECT_LOCK (gtk_sink);
-  if (gtk_sink->widget != NULL)
-    widget = g_object_ref (gtk_sink->widget);
-  GST_OBJECT_UNLOCK (gtk_sink);
-
-  if (!widget)
-    widget =
-        gst_gtk_invoke_on_main ((GThreadFunc) gst_gtk_base_sink_get_widget,
-        gtk_sink);
-
-  return widget;
+  return gtk_sink->widget;
 }
 
 static void
@@ -279,7 +221,19 @@ gst_gtk_base_sink_get_property (GObject * object, guint prop_id,
   switch (prop_id) {
     case PROP_WIDGET:
     {
-      g_value_take_object (value, gst_gtk_base_sink_acquire_widget (gtk_sink));
+      GObject *widget = NULL;
+
+      GST_OBJECT_LOCK (gtk_sink);
+      if (gtk_sink->widget != NULL)
+        widget = G_OBJECT (gtk_sink->widget);
+      GST_OBJECT_UNLOCK (gtk_sink);
+
+      if (!widget)
+        widget =
+            gst_gtk_invoke_on_main ((GThreadFunc) gst_gtk_base_sink_get_widget,
+            gtk_sink);
+
+      g_value_set_object (value, widget);
       break;
     }
     case PROP_FORCE_ASPECT_RATIO:
@@ -288,10 +242,6 @@ gst_gtk_base_sink_get_property (GObject * object, guint prop_id,
     case PROP_PIXEL_ASPECT_RATIO:
       gst_value_set_fraction (value, gtk_sink->par_n, gtk_sink->par_d);
       break;
-    case PROP_VIDEO_ASPECT_RATIO_OVERRIDE:
-      gst_value_set_fraction (value, gtk_sink->video_par_n,
-          gtk_sink->video_par_d);
-      break;
     case PROP_IGNORE_ALPHA:
       g_value_set_boolean (value, gtk_sink->ignore_alpha);
       break;
@@ -315,10 +265,6 @@ gst_gtk_base_sink_set_property (GObject * object, guint prop_id,
       gtk_sink->par_n = gst_value_get_fraction_numerator (value);
       gtk_sink->par_d = gst_value_get_fraction_denominator (value);
       break;
-    case PROP_VIDEO_ASPECT_RATIO_OVERRIDE:
-      gtk_sink->video_par_n = gst_value_get_fraction_numerator (value);
-      gtk_sink->video_par_d = gst_value_get_fraction_denominator (value);
-      break;
     case PROP_IGNORE_ALPHA:
       gtk_sink->ignore_alpha = g_value_get_boolean (value);
       break;
@@ -330,33 +276,16 @@ gst_gtk_base_sink_set_property (GObject * object, guint prop_id,
 
 static void
 gst_gtk_base_sink_navigation_send_event (GstNavigation * navigation,
-    GstEvent * event)
+    GstStructure * structure)
 {
   GstGtkBaseSink *sink = GST_GTK_BASE_SINK (navigation);
+  GstEvent *event;
   GstPad *pad;
-  gdouble x, y;
-
-  event = gst_event_make_writable (event);
-
-  if (gst_navigation_event_get_coordinates (event, &x, &y)) {
-    GtkGstBaseWidget *widget = gst_gtk_base_sink_get_widget (sink);
-    gdouble stream_x, stream_y;
-
-    if (widget == NULL) {
-      GST_ERROR_OBJECT (sink, "Could not ensure GTK initialization.");
-      return;
-    }
-
-    gtk_gst_base_widget_display_size_to_stream_size (widget,
-        x, y, &stream_x, &stream_y);
-    gst_navigation_event_set_coordinates (event, stream_x, stream_y);
-    g_object_unref (widget);
-  }
 
+  event = gst_event_new_navigation (structure);
   pad = gst_pad_get_peer (GST_VIDEO_SINK_PAD (sink));
 
-  GST_TRACE_OBJECT (sink, "navigation event %" GST_PTR_FORMAT,
-      gst_event_get_structure (event));
+  GST_TRACE_OBJECT (sink, "navigation event %" GST_PTR_FORMAT, structure);
 
   if (GST_IS_PAD (pad) && GST_IS_EVENT (event)) {
     if (!gst_pad_send_event (pad, gst_event_ref (event))) {
@@ -373,7 +302,7 @@ gst_gtk_base_sink_navigation_send_event (GstNavigation * navigation,
 static void
 gst_gtk_base_sink_navigation_interface_init (GstNavigationInterface * iface)
 {
-  iface->send_event_simple = gst_gtk_base_sink_navigation_send_event;
+  iface->send_event = gst_gtk_base_sink_navigation_send_event;
 }
 
 static gboolean
@@ -382,13 +311,9 @@ gst_gtk_base_sink_start_on_main (GstBaseSink * bsink)
   GstGtkBaseSink *gst_sink = GST_GTK_BASE_SINK (bsink);
   GstGtkBaseSinkClass *klass = GST_GTK_BASE_SINK_GET_CLASS (bsink);
   GtkWidget *toplevel;
-  GtkGstBaseWidget *widget;
 
-  widget = gst_gtk_base_sink_get_widget (gst_sink);
-  if (!widget) {
-    GST_ERROR_OBJECT (bsink, "Could not ensure GTK initialization.");
+  if (gst_gtk_base_sink_get_widget (gst_sink) == NULL)
     return FALSE;
-  }
 
   /* After this point, gtk_sink->widget will always be set */
 
@@ -407,15 +332,13 @@ gst_gtk_base_sink_start_on_main (GstBaseSink * bsink)
         G_CALLBACK (window_destroy_cb), gst_sink);
   }
 
-  g_object_unref (widget);
-
   return TRUE;
 }
 
 static gboolean
 gst_gtk_base_sink_start (GstBaseSink * bsink)
 {
-  return !!gst_gtk_invoke_on_main ((GThreadFunc)
+  return ! !gst_gtk_invoke_on_main ((GThreadFunc)
       gst_gtk_base_sink_start_on_main, bsink);
 }
 
@@ -439,7 +362,7 @@ gst_gtk_base_sink_stop (GstBaseSink * bsink)
   GstGtkBaseSink *gst_sink = GST_GTK_BASE_SINK (bsink);
 
   if (gst_sink->window)
-    return !!gst_gtk_invoke_on_main ((GThreadFunc)
+    return ! !gst_gtk_invoke_on_main ((GThreadFunc)
         gst_gtk_base_sink_stop_on_main, bsink);
 
   return TRUE;
@@ -459,8 +382,8 @@ gst_gtk_base_sink_change_state (GstElement * element, GstStateChange transition)
   GstStateChangeReturn ret = GST_STATE_CHANGE_SUCCESS;
 
   GST_DEBUG_OBJECT (element, "changing state: %s => %s",
-      gst_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
-      gst_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
+      gst_element_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
+      gst_element_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
 
   ret = GST_ELEMENT_CLASS (parent_class)->change_state (element, transition);
   if (ret == GST_STATE_CHANGE_FAILURE)
