@@ -57,11 +57,7 @@ struct _GstSpeexEnc {
 
   SpeexBits             bits;
   SpeexHeader           header;
-#ifdef SPEEX_1_0
-  SpeexMode             *speex_mode;
-#else
   const SpeexMode       *speex_mode;
-#endif
   void                  *state;
 
   /* properties */
@@ -80,6 +76,7 @@ struct _GstSpeexEnc {
   gint                  rate;
 
   gboolean              header_sent;
+  guint64               encoded_samples;
 
   GstTagList            *tags;
 
