@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GST_RTP_SSRC_DEMUX_H__
@@ -36,8 +36,6 @@ struct _GstRtpSsrcDemux
 {
   GstElement parent;
 
-  GstSegment   segment;
-
   GstPad *rtp_sink;
   GstPad *rtcp_sink;
 
