@@ -31,10 +31,9 @@
 
 #include "gstv4l2object.h"
 #include "gstv4l2vp9enc.h"
-#include "gstv4l2vp9codec.h"
 
 #include <string.h>
-#include <glib/gi18n-lib.h>
+#include <gst/gst-i18n-plugin.h>
 
 GST_DEBUG_CATEGORY_STATIC (gst_v4l2_vp9_enc_debug);
 #define GST_CAT_DEFAULT gst_v4l2_vp9_enc_debug
@@ -66,6 +65,45 @@ gst_v4l2_vp9_enc_get_property (GObject * object,
   /* TODO */
 }
 
+static gint
+v4l2_profile_from_string (const gchar * profile)
+{
+  gint v4l2_profile = -1;
+
+  if (g_str_equal (profile, "0"))
+    v4l2_profile = 0;
+  else if (g_str_equal (profile, "1"))
+    v4l2_profile = 1;
+  else if (g_str_equal (profile, "2"))
+    v4l2_profile = 2;
+  else if (g_str_equal (profile, "3"))
+    v4l2_profile = 3;
+  else
+    GST_WARNING ("Unsupported profile string '%s'", profile);
+
+  return v4l2_profile;
+}
+
+static const gchar *
+v4l2_profile_to_string (gint v4l2_profile)
+{
+  switch (v4l2_profile) {
+    case 0:
+      return "0";
+    case 1:
+      return "1";
+    case 2:
+      return "2";
+    case 3:
+      return "3";
+    default:
+      GST_WARNING ("Unsupported V4L2 profile %i", v4l2_profile);
+      break;
+  }
+
+  return NULL;
+}
+
 static void
 gst_v4l2_vp9_enc_init (GstV4l2Vp9Enc * self)
 {
@@ -89,7 +127,7 @@ gst_v4l2_vp9_enc_class_init (GstV4l2Vp9EncClass * klass)
 
   gst_element_class_set_static_metadata (element_class,
       "V4L2 VP9 Encoder",
-      "Codec/Encoder/Video/Hardware",
+      "Codec/Encoder/Video",
       "Encode VP9 video streams via V4L2 API",
       "Nicolas Dufresne <nicolas.dufresne@collabora.com");
 
@@ -99,6 +137,9 @@ gst_v4l2_vp9_enc_class_init (GstV4l2Vp9EncClass * klass)
       GST_DEBUG_FUNCPTR (gst_v4l2_vp9_enc_get_property);
 
   baseclass->codec_name = "VP9";
+  baseclass->profile_cid = V4L2_CID_MPEG_VIDEO_VPX_PROFILE;
+  baseclass->profile_to_string = v4l2_profile_to_string;
+  baseclass->profile_from_string = v4l2_profile_from_string;
 }
 
 /* Probing functions */
@@ -111,11 +152,9 @@ gst_v4l2_is_vp9_enc (GstCaps * sink_caps, GstCaps * src_caps)
 
 void
 gst_v4l2_vp9_enc_register (GstPlugin * plugin, const gchar * basename,
-    const gchar * device_path, gint video_fd, GstCaps * sink_caps,
-    GstCaps * src_caps)
+    const gchar * device_path, GstCaps * sink_caps, GstCaps * src_caps)
 {
-  const GstV4l2Codec *codec = gst_v4l2_vp9_get_codec ();
   gst_v4l2_video_enc_register (plugin, GST_TYPE_V4L2_VP9_ENC,
-      "vp9", basename, device_path, codec, video_fd, sink_caps,
+      "vp9", basename, device_path, sink_caps,
       gst_static_caps_get (&src_template_caps), src_caps);
 }
